@@ -35,6 +35,7 @@ from samtranslator.public.translator import ManagedPolicyLoader
 from samtranslator.translator.transform import transform
 from samtranslator.yaml_helper import yaml_parse
 from samtranslator.model.exceptions import InvalidDocumentException
+from samtranslator.feature_toggle.feature_toggle import FeatureToggleLocalConfigProvider, FeatureToggle
 
 LOG = logging.getLogger(__name__)
 cli_options = docopt(__doc__)
@@ -95,7 +96,15 @@ def transform_template(input_file_path, output_file_path):
         sam_template = yaml_parse(f)
 
     try:
-        cloud_formation_template = transform(sam_template, {}, ManagedPolicyLoader(iam_client))
+        feature_toggle = FeatureToggle(
+            FeatureToggleLocalConfigProvider(
+                os.path.join(my_path, "..", "tests", "feature_toggle", "input", "feature_toggle_config.json")
+            ),
+            stage=None,
+            account_id=None,
+            region=None,
+        )
+        cloud_formation_template = transform(sam_template, {}, ManagedPolicyLoader(iam_client), feature_toggle)
         cloud_formation_template_prettified = json.dumps(cloud_formation_template, indent=2)
 
         with open(output_file_path, "w") as f:
