@@ -1,9 +1,10 @@
 from parameterized import parameterized, param
 
-import pytest
 from unittest import TestCase
 from samtranslator.sdk.parameter import SamParameterValues
-from mock import patch
+from mock import patch, Mock
+
+from samtranslator.translator.arn_generator import NoRegionFound
 
 
 class TestSAMParameterValues(TestCase):
@@ -101,3 +102,10 @@ class TestSAMParameterValues(TestCase):
         sam_parameter_values = SamParameterValues(parameter_values)
         sam_parameter_values.add_pseudo_parameter_values()
         self.assertEqual(expected, sam_parameter_values.parameter_values)
+
+    def test_add_pseudo_parameter_values_raises_NoRegionFound(self):
+        boto_session_mock = Mock()
+        boto_session_mock.region_name = None
+        sam_parameter_values = SamParameterValues({})
+        with self.assertRaises(NoRegionFound):
+            sam_parameter_values.add_pseudo_parameter_values(session=boto_session_mock)
